<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Informazioni </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autore</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Dona</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licenza: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished">s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Immagine filigrana necessaria</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>È necessario aggiungere un&apos;immagine Filigrana tramite il menù Opzioni &gt; Impostazioni &gt; Annotatore &gt; Aggiorna</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Smussa i tratti di pennello</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Se abilitato, smussa i tratti di penna e pennarello
dopo che sono stati tracciati.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Fattore di smussamento</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>All&apos;aumentare del fattore di smussamento diminuirà la precisione, ma aumenterà la levigazione del tratto di penna/pennarello.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Impostazioni Annotatore</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Salva una schermata all&apos;avvio usando la modalità di default</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Stile applicazione</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Imposta lo stile dell&apos;applicazione: ciò definisce l&apos;aspetto estetico dell&apos;interfaccia.
Questa impostazione richiede il riavvio.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Impostazioni Applicazione</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Copia automaticamente le nuove catture negli appunti</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Usa l&apos;interfaccia con le schede</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Questo cambio richiede far ripartire l&apos;applicazione</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Usa ksnip in una sola finestra</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Collaboratori:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Traduzione in spagnolo</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Traduzione in olandese</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Traduzione in russo</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Traduzione in Bokmål norvegese</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Traduzione in francese</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Traduzione in polacco</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Versione Snap &amp; Flatpack</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Attenzione - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>La cattura %1%2%3 è stata modificata
Vuoi salvarla?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Traccia un&apos;area rettangolare con il mouse</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Cattura usando la ultima area rettangolare usata</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Cattura di tutti gli schermi collegati</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Acquisisci lo schermo nella posizione del mouse</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Acquisisci la finestra attualmente in primo piano</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Cattura ciò che si trova attualmente sotto il cursore del mouse</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>please join our </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please use </source>
        <translation type="unfinished">Usa </translation>
    </message>
    <message>
        <source> to report bugs.</source>
        <translation type="unfinished"> per segnalare malfunzionamenti.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>here</source>
        <translation>qui</translation>
    </message>
    <message>
        <source>Also possible, </source>
        <translation>Anche possibile, </translation>
    </message>
    <message>
        <source>Donations are always welcome</source>
        <translation>Le donazioni sono sempre ben accette</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Donazione</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Area rettangolare</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation type="unfinished">Ultima area rettangolare usata</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished">Schermo completo (tutti gli schermi)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation type="unfinished">Schermo attuale</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation type="unfinished">Finestra attiva</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation type="unfinished">Finestra sotto il cursore</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Portale schermate</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Il caricamento è andato a buon fine</translation>
    </message>
    <message>
        <source>Upload script </source>
        <translation>Carica script</translation>
    </message>
    <message>
        <source> finished successfully.</source>
        <translation>finito con successo</translation>
    </message>
    <message>
        <source>Uploaded to</source>
        <translation>Caricato su</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Impossibile salvare l&apos;immagine temporanea per il caricamento.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Impossibile avviare il processo, controllare il percorso e le autorizzazioni.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Il processo si è interrotto</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Processo scaduto.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Errore in lettura del processo.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Errore in scrittura del processo.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Errore Web, controlla l&apos;output della console.</translation>
    </message>
    <message>
        <source>Unknown process error.</source>
        <translation>Errore di processo sconosciuto.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Caricamento fallito</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Abilita scorciatoie globali</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Acquisisci area rettangolare</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Acquisisci l&apos;ultima area rettangolare</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Acquisisci l&apos;intero schermo</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Acquisisci lo Schermo attuale</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Acquisisci la finestra attiva</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Acquisisci la finestra sotto il Cursore</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Scorciatoie Globali</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Includi il cursore del mouse nell&apos;acquisizione schermo</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Il cursore del mouse dovrebbe essere visibile su
screenshot.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Generic Wayland Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Generic Wayland Screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation type="unfinished">Cronologia di Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Cancella Link</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Il caricamento su imgur.com è stato completato!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Ricevuto nuovo token,nuova prova di upload in corso…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Il token Imgur è scaduto, richiesta nuovo token in corso…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Forza caricamento anonimo</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Dopo aver caricato, apri il link Imgur nel browser predefinito</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Copia sempre il link Imgur negli Appunti</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>ID Client</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Client Secreto</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Inserisci il Pin imgur che verrà scambiato con un token.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Ottieni PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Ottieni Token</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Cronologia Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Carica Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome Utente</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>In attesa di imgur.com...</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Token Imgur.com aggiornato correttamente.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Errore di aggiornamento del token imgur.com.</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Link direttamente all&apos;immagine</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Ritardo in secondi tra l&apos;attivazione
e cattura screenshot.</translation>
    </message>
    <message>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Salva Cattura Schermo nel file system</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Copia Cattura Schermo negli Appunti</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rifai</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Ritaglia</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Ritaglia Cattura Schermo</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation>Impossibile mostrare l&apos;immagine</translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation>Non Salvato</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Apre la finestra di dialogo della stampante e fornisci l&apos;opzione per stampare l&apos;immagine</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Anteprima di Stampa</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Apre la finestra di dialogo Anteprima di stampa in cui è possibile modificare l&apos;orientamento dell&apos;immagine</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Scala</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Aggiungi Filigrana</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Aggiungi filigrana all&apos;immagine acquisita. È possibile aggiungere più filigrane.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>FIle</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>File immagine (*.png *.jpg *.bmp)</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Salva Come...</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation type="unfinished">Incollaggio Incorporato</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished">Salva Come</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Copia</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Cattura</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Chiudi</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Successfully renamed image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Salva Come</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tutti i FIle</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Immagine Salvata</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Salvato in</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Salvataggio Immagine Fallito</translation>
    </message>
    <message>
        <source>Failed to save image to</source>
        <translation>Salvataggio Immagine fallito in</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation type="unfinished">Salva automaticamente le nuove acquisizioni nella posizione predefinita</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished">Chiedi conferma prima di scartare i cambiamenti non salvati</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation type="unfinished">Ricorda l&apos;ultima directory di salvataggio</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished">Se abilitato, sovrascriverà la directory di salvataggio memorizzata nelle impostazioni
con l&apos;ultima directory di salvataggio, per ogni salvataggio.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished">Posizione e nome del file per il salvataggio</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Sfoglia</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation type="unfinished">Posizione di salvataggio della schermata</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Sfoglia</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Impostazioni</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation type="unfinished">Carica Imgur</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished">Blocca l&apos;immagine durante lo snipping</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished">Mostra la lente d&apos;ingrandimento sull&apos;area di cattura</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished">Mostra righelli area di cattura</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished">Linee orizzontali e verticali che vanno da
bordi del desktop per il cursore sull&apos;area di cattura.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished">Mostra le informazioni sulla posizione e sulla dimensione dell&apos;area di cattura</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished">Colore del cursore dell&apos;area di cattura</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished">Spessore cursore area di cattura</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished">Mostra icona nel vassoio di sistema</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished">Se abilitato, mostrerà un&apos;icona nel vassoio di sistema se il DE lo supporta.
Questa impostazione richiede il riavvio.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished">Minimizza nel vassoio</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished">Iniziare minimizzato nella barra delle applicazione</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished">Chiudi nel vassoio</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture</source>
        <translation type="unfinished">Cattura</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Tray icon notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished">Immagini</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished">Tutti i FIle</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation type="unfinished">Versione</translation>
    </message>
    <message>
        <source>Build</source>
        <translation type="unfinished">Build</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation type="unfinished">Utilizza:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished">Immagine di filigrana</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Aggiorna</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished">Ruota immagine</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished">Se abilitato, l&apos;immagine verrà aggiunta con una rotazione di 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
